@@ -14,19 +14,21 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _BackupProfileWidget_h_
 #define _BackupProfileWidget_h_
 
 #include <ktabctl.h>
-#include <qstrlist.h>
+#include <q3strlist.h>
+//Added by qt3to4:
+#include <QLabel>
 
 class QCheckBox;
 class QComboBox;
 class QLabel;
 class QLineEdit;
-class QListBox;
+class Q3ListBox;
 
 class BackupProfile;
 
@@ -37,7 +39,7 @@ class BackupProfileWidget : public KTabCtl {
     Q_OBJECT
     QLineEdit* _archiveName;
     QComboBox* _workingDir;
-    QListBox*  _files;
+    Q3ListBox*  _files;
     QCheckBox* _oneFilesystem;
     QCheckBox* _incremental;
     QLabel*    _snapshotLabel;
