@@ -18,14 +18,16 @@
 
 #include <stdlib.h>
 
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
+#include <QComboBox>
+#include <QLabel>
+#include <QLayout>
+#include <QLineEdit>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
 
-#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
 
@@ -61,9 +63,9 @@ FormatOptDlg::FormatOptDlg( const QString & def, QWidget* parent, const char* na
     _tapeSizeUnits->insertItem( "MB" );
     _tapeSizeUnits->insertItem( "GB" );
 
-    KPushButton* ok     = new KPushButton( KStdGuiItem::ok(), this );
+    KPushButton* ok     = new KPushButton( KStandardGuiItem::ok(), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
-    KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
+    KPushButton* cancel = new KPushButton( KStandardGuiItem::cancel(), this );
     cancel->setFixedSize( 80, cancel->sizeHint().height() );
 
     QVBoxLayout* l1 = new QVBoxLayout( this, 8, 4 );
