@@ -1,7 +1,6 @@
 /*
-** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+** Copyright (C) 1999,2007 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
-// Author: Damyan Pepper
 // Author: Toivo Pedaste
 */
 
@@ -18,40 +17,39 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
-
-#include "../config.h"
 // Standard headers
 #include <stdio.h>
 
 // Qt headers
+#include <QtGui/QApplication>
+#include <QtCore/QFileInfo>
+#include <QtGui/QTextEdit>
+//Added by qt3to4:
+#include <QtGui/QPixmap>
 
-#include <qapplication.h>
-#include <qfileinfo.h>
-#include <qtextedit.h>
-
+#include <kdebug.h>
 #include <kiconloader.h>
 #include <kglobal.h>
 #include <krun.h>
-#include <kopenwith.h>
 
 // kpackage.headers
 #include "kpackage.h"
 #include "packageDisplay.h"
+#include "packageDepends.h"
 #include "packageProperties.h"
 #include "pkgInterface.h"
+#include "kpSettings.h"
 #include "utils.h"
-#include "options.h"
 #include <klocale.h>
 
-extern Opts *opts;
 
 // constructor
 packageDisplayWidget::packageDisplayWidget(QWidget *parent)
@@ -78,31 +76,36 @@ packageDisplayWidget::~packageDisplayWidget()
 
 void packageDisplayWidget::setupWidgets()
 {
-  proptab = new QVBox( this);
+  proptab = new KVBox( this);
   curTab = proptab;
-  fltab = new QVBox( this);
-  cltab = new QVBox( this);
+  deptab = new KVBox( this);
+  fltab = new KVBox( this);
+  cltab = new KVBox( this);
 
   packageProperties = new packagePropertiesWidget(proptab);
-
+  depends = new packageDepends(deptab);
+  
   fileList = new kpFileList(fltab, this);
-  connect(fileList, SIGNAL(executed(QListViewItem *)),
-            this, SLOT( openBinding(QListViewItem *)) );
-  connect(fileList, SIGNAL(returnPressed(QListViewItem *)),
-            this, SLOT( openBinding(QListViewItem *)) );
+  connect(fileList, SIGNAL(executed(Q3ListViewItem *)),
+            this, SLOT( openBinding(Q3ListViewItem *)) );
+  connect(fileList, SIGNAL(returnPressed(Q3ListViewItem *)),
+            this, SLOT( openBinding(Q3ListViewItem *)) );
 
   changeLog = new QTextEdit(cltab);
 
   addTab(proptab, i18n("Properties"));
+  addTab(deptab, i18n("Dependencies List"));
   addTab(fltab, i18n("File List"));
   addTab(cltab, i18n("Change Log"));
 
-  if (isTabEnabled(cltab))
-    setTabEnabled(cltab,false);
-  if (isTabEnabled(fltab))
-    setTabEnabled(fltab,false);
-  if (isTabEnabled(proptab))
-    setTabEnabled(proptab,false);
+  if (isTabEnabled(indexOf (cltab)))
+      setTabEnabled(indexOf (cltab),false);
+  if (isTabEnabled(indexOf (deptab)))
+      setTabEnabled(indexOf (deptab),false);
+  if (isTabEnabled(indexOf (fltab)))
+      setTabEnabled(indexOf (fltab),false);
+  if (isTabEnabled(indexOf (proptab)))
+      setTabEnabled(indexOf (proptab),false);
 
   connect(this,SIGNAL(currentChanged(QWidget *)), this, SLOT(tabSelected(QWidget *)));
 }
@@ -118,13 +121,23 @@ void packageDisplayWidget::tabSet(QWidget *tab)
   disconnect(this,SIGNAL(currentChanged(QWidget *)), this, SLOT(tabSelected(QWidget *)));
   if(tab == proptab) {
     packageProperties->show();
+    depends->hide();
     fileList->hide();
     changeLog->hide();
-    setCurrentPage(0);
+    setCurrentIndex(0);
+  } else if (tab == deptab) {
+    packageProperties->hide();
+    depends->show();
+    fileList->hide();
+    changeLog->hide();
+    updateDepends();
+    setCurrentIndex(1);
   } else if (tab == fltab) {
     packageProperties->hide();
+    depends->hide();
+    fileList->hide();
     changeLog->hide();
-    if (isTabEnabled(fltab)) {
+    if (isTabEnabled(indexOf (fltab))) {
       if (!initList) {
 	updateFileList();
 	initList = 1;
@@ -133,17 +146,18 @@ void packageDisplayWidget::tabSet(QWidget *tab)
     } else {
       fileList->hide();
     }
-    setCurrentPage(1);
+    setCurrentIndex(2);
   } else {
+   packageProperties->hide();
+    depends->hide();
     fileList->hide();
-    packageProperties->hide();
-    if (isTabEnabled(cltab)) {
+    if (isTabEnabled(indexOf (cltab))) {
       updateChangeLog();
       changeLog->show();
     } else {
       changeLog->hide();
     }
-    setCurrentPage(2);
+    setCurrentIndex(3);
   }
   connect(this,SIGNAL(currentChanged(QWidget *)), this, SLOT(tabSelected(QWidget *)));
 }
@@ -151,22 +165,20 @@ void packageDisplayWidget::tabSet(QWidget *tab)
 void packageDisplayWidget::noPackage()
 {
   disconnect(this,SIGNAL(currentChanged(QWidget *)), this, SLOT(tabSelected(QWidget *)));
-  
-  if (isTabEnabled(fltab)) {
-    fileList->setColumnText(0,"");
-    setTabEnabled(fltab,false);
-  }
-  if (isTabEnabled(proptab))
-    setTabEnabled(proptab,false);
-  if (isTabEnabled(cltab))
-    setTabEnabled(cltab,false);
+//         kDebug() <<  "packageDisplayWidget::noPackage\n";
+  setTabEnabled(indexOf (proptab),false);
+  setTabEnabled(indexOf (deptab),false);
+  setTabEnabled(indexOf (fltab),false);
+  setTabEnabled(indexOf (cltab),false);
 
   packageProperties->changePackage(NULL);
 
   packageProperties->setText("");
   fileList->clear();
+  fileList->setColumnText(0,"");
   changeLog->setText("");
-
+  depends->setText("");
+  
   connect(this,SIGNAL(currentChanged(QWidget *)), this, SLOT(tabSelected(QWidget *)));
 }
 
@@ -176,16 +188,16 @@ void packageDisplayWidget::changePackage(packageInfo *p)
 
 // This is to stop selectionChanged firing off here
 
-    disconnect(fileList, SIGNAL(executed(QListViewItem *)),
-            this, SLOT( openBinding(QListViewItem *)) );
-  disconnect(fileList, SIGNAL(returnPressed(QListViewItem *)),
-            this, SLOT( openBinding(QListViewItem *)) );
-  disconnect(fileList, SIGNAL(contextMenu(KListView *, QListViewItem *, const QPoint &)),
-            fileList, SLOT( openContext(KListView *, QListViewItem *, const QPoint &)) );
+    disconnect(fileList, SIGNAL(executed(Q3ListViewItem *)),
+            this, SLOT( openBinding(Q3ListViewItem *)) );
+  disconnect(fileList, SIGNAL(returnPressed(Q3ListViewItem *)),
+            this, SLOT( openBinding(Q3ListViewItem *)) );
+  disconnect(fileList, SIGNAL(contextMenu(K3ListView *, Q3ListViewItem *, const QPoint &)),
+            fileList, SLOT( openContext(K3ListView *, Q3ListViewItem *, const QPoint &)) );
 
 
   if (package && package != p) {
-    if (!package->getItem() && !kpackage->management->allPackages->find(package)) {
+    if (!package->getItem() && !kpackage->management->allPackages.contains(package)) {
       delete package;
       package = 0;
     }
@@ -197,48 +209,66 @@ void packageDisplayWidget::changePackage(packageInfo *p)
   } else {
     QString u = package->getFilename();
     if (!package->updated &&  !u.isEmpty()) {
-      packageInfo *np = package->interface->getPackageInfo('u', u, 0);
+      packageInfo *np = package->interface->getFPackageInfo(u);
 
-      if (np) {
-	QDictIterator<QString> it(*(np->getDict())); // update info entries in p
-	while (it.current()) {
-	  package->info->replace(it.currentKey(),new QString(*(it.current())));
-	  ++it;
+      if (np) { 
+	QMapIterator<QString, QString> it(np->info);
+	while (it.hasNext()) {
+	  it.next();
+	  package->info.insert(it.key(),it.value());
 	}
 	package->interface = np->interface;
 	delete np;
-	package->updated = TRUE;
+	package->updated = true;
+	package->updateItem();
       }
     }
 
     initList = 0;
+    
     packageProperties->changePackage(package);
+    if (package->interface->filesTab(package))
+      setTabEnabled(indexOf (fltab),true);
+    else
+      setTabEnabled(indexOf (fltab),false);
+
+    if (package->interface->depTab(package))
+      setTabEnabled(indexOf (deptab),true);
+    else
+      setTabEnabled(indexOf (deptab),false);
+
 
     if (package->interface->changeTab(package))
-      setTabEnabled(cltab,true);
+      setTabEnabled(indexOf (cltab),true);
     else
-      setTabEnabled(cltab,false);
+      setTabEnabled(indexOf (cltab),false);
 
-    if (package->interface->filesTab(package))
-      setTabEnabled(fltab,true);
-    else
-      setTabEnabled(fltab,false);
-
-    setTabEnabled(proptab,true);
+    setTabEnabled(indexOf (proptab),true);
  
     tabSet(curTab);
 
 
   }
-    connect(fileList, SIGNAL(executed(QListViewItem *)),
-            this, SLOT( openBinding(QListViewItem *)) );
-  connect(fileList, SIGNAL(returnPressed(QListViewItem *)),
-            this, SLOT( openBinding(QListViewItem *)) );
-  connect(fileList, SIGNAL(contextMenu(KListView *, QListViewItem *, const QPoint &)),
-            fileList, SLOT( openContext(KListView *, QListViewItem *, const QPoint &)) );
+    connect(fileList, SIGNAL(executed(Q3ListViewItem *)),
+            this, SLOT( openBinding(Q3ListViewItem *)) );
+  connect(fileList, SIGNAL(returnPressed(Q3ListViewItem *)),
+            this, SLOT( openBinding(Q3ListViewItem *)) );
+  connect(fileList, SIGNAL(contextMenu(K3ListView *, Q3ListViewItem *, const QPoint &)),
+            fileList, SLOT( openContext(K3ListView *, Q3ListViewItem *, const QPoint &)) );
 
  }
 
+void packageDisplayWidget::updateDepends()
+{
+  if (!package)
+    return;
+  
+  depends->clear();
+  if (package->depends == 0)
+    package->interface->getPackageDepends(package);
+  depends->changePackage(package);
+}
+
 void packageDisplayWidget::updateChangeLog()
 {
   if (!package)
@@ -248,7 +278,6 @@ void packageDisplayWidget::updateChangeLog()
   QString stmp;
   lines = package->interface->getChangeLog(package);
 
-
   changeLog->setTextFormat(Qt::LogText);
   changeLog->hide();
   if (lines.count() > 1) {
@@ -264,10 +293,8 @@ void packageDisplayWidget::updateChangeLog()
   } else {
     changeLog->setText(i18n(" - No change log -"));
   }
-
   changeLog->show();
-  changeLog->setContentsPos(0,0);
-
+  changeLog->scroll(-99999,-9999);
 }
 
 void packageDisplayWidget::updateFileList()
@@ -276,7 +303,6 @@ void packageDisplayWidget::updateFileList()
     return;
 
   // Get a list of files in the package
-  QStringList files;
   QStringList errorfiles;
 
   // set the status
@@ -284,44 +310,37 @@ void packageDisplayWidget::updateFileList()
 
   // clear the file list
   fileList->clear();
+  fileList->setColumnText(0, "");
 
-  // Check if the package is installed
-  int installed;
-  if(package->getFilename().isEmpty()) {
-    if(package->packageState == packageInfo::UPDATED) {
-      fileList->setColumnText(0, "");
-      return;
-    } else
-      installed=1;
-  } else
-    installed=0;
-
-  files = package->interface->getFileList(package);
-
-  if (files.count() == 0)
+  if (package->files == 0) 
+    package->interface->getFileList(package);
+  
+//        kDebug() << "files.count=" << package->files->count() << "\n";
+  if (package->files->count() == 0)
     return;
 
   // Get a list of files that failed verification
-  if(installed && opts->VerifyFL) {
-    errorfiles = package->interface->verify(package, files);
+  if (kpkg->conf->verify) {
+    errorfiles = package->interface->verify(package, *package->files);
   }
 
   kpackage->setStatus(i18n("Updating File List"));
 
   uint c=0, p=0;
-  uint step = (files.count() / 100) + 1;
+  uint step = (package->files->count() / 100) + 1;
 
   QString ftmp;
-  ftmp.setNum(files.count());
+  ftmp.setNum(package->files->count());
   ftmp += i18n(" Files");
 
   fileList->setColumnText(0, ftmp);
+  fileList->hide();
   fileList->setSorting(-1);
 
-  QListViewItem *q;
+  Q3ListViewItem *q;
 
   // Go through all the files
-  for (QStringList::ConstIterator it = files.begin(); (it != files.end());  ) {
+  for (QStringList::ConstIterator it = package->files->begin(); (it != package->files->end());  ) {
     // Update the status progress
     c++;
     if(c > step) {
@@ -331,13 +350,11 @@ void packageDisplayWidget::updateFileList()
     }
 
     int error=0;
-     
-     QString cur = *it;
-     it++;
-     QPixmap pixmap;
-     
-    if (installed) { // see if file failed verification,
 
+      QString cur = *it;
+      it++;
+      QPixmap pixmap;
+     
       if ( errorfiles.count() > 0) {
 	for( QStringList::ConstIterator itError = errorfiles.begin();
 	     (itError != errorfiles.end());
@@ -347,91 +364,85 @@ void packageDisplayWidget::updateFileList()
 	  }
 	}
       }
-       if(error) pixmap=cross;
+       if(error) 
+	 pixmap=cross;
        else 
-        pixmap=tick;
-       
-     } else 
-       pixmap=question;    
-     
+         pixmap=tick;
+    
      q = fileList->insert(cur, pixmap);   
  }
 
   fileList->setSorting(0);
+  fileList->show();
   kpackage->setPercent(100);
 }
   
- kpFileList::kpFileList(QWidget* parent, packageDisplayWidget* parent2) : KListView(parent)
+ kpFileList::kpFileList(QWidget* parent, packageDisplayWidget* parent2) : K3ListView(parent)
  {
    hide();
    addColumn("name");
-   setRootIsDecorated(TRUE);
-   connect(this, SIGNAL(contextMenu(KListView *, QListViewItem *, const QPoint &)),
-             this, SLOT( openContext(KListView *, QListViewItem *, const QPoint &)) );
+   setRootIsDecorated(true);
+   connect(this, SIGNAL(contextMenu(K3ListView *, Q3ListViewItem *, const QPoint &)),
+             this, SLOT( openContext(K3ListView *, Q3ListViewItem *, const QPoint &)) );
             
-   FileListMenu = new KPopupMenu();
-   openwith = FileListMenu->insertItem(i18n("&Open With..."),parent2,SLOT(__openBindingWith()));
+   FileListMenu = new KMenu();
+   openwith = FileListMenu->insertItem(i18n("&Open With..."),parent2,SLOT(__openBindingWith()));	// what to do with this insertItem()?
    
    pkDisplay = parent2;
  }
- 
- 
+
  void packageDisplayWidget::__openBindingWith()
  {
         openBindingWith(fileList->selectedItem());
  }
  
- void packageDisplayWidget::openBindingWith(QListViewItem *index)
+ void packageDisplayWidget::openBindingWith(Q3ListViewItem *index)
  {      
      if ( !index ) return; 
-     KURL url;
+     KUrl url;
      if (package && package->packageState == packageInfo::INSTALLED) {
        url.setPath( fileList->item2Path(index) ); // from local file to URL
-       KRun::displayOpenWithDialog(KURL::List::List(url) );
+       KRun::displayOpenWithDialog(KUrl::List::List(url),this );
       }      
  }
- 
- 
- void kpFileList::openContext(KListView *, QListViewItem *, const QPoint &p)
+
+ void kpFileList::openContext(K3ListView *, Q3ListViewItem *, const QPoint &p)
  {
-        FileListMenu->setItemEnabled(openwith, 
-        (selectedItem() && pkDisplay->package && pkDisplay->package->getFilename().isEmpty()) ? TRUE : FALSE);
-        FileListMenu->exec(p);  
- 
+        FileListMenu->setItemEnabled(openwith,
+        (selectedItem() && pkDisplay->package && pkDisplay->package->getFilename().isEmpty()) ? true : false);
+        FileListMenu->exec(p);
  }
- 
- void kpFileList::clear() 
+
+ void kpFileList::clear()
  {
-        KListView::clear();
+        K3ListView::clear();
  }
- 
- QString kpFileList::item2Path(QListViewItem *it)
+
+ QString kpFileList::item2Path(Q3ListViewItem *it)
  {
         QString res;
         res = it ? it->text(0) : NULL;  
         return res;
  }
- 
- 
- QListViewItem* kpFileList::insert(const QString &cur, const QPixmap &pixmap)
- {
-   QListViewItem* q;
 
-   q = new QListViewItem(this, cur);
+ Q3ListViewItem* kpFileList::insert(const QString &cur, const QPixmap &pixmap)
+ {
+   Q3ListViewItem* q;
+
+   q = new Q3ListViewItem(this, cur);
    if (q) 
      q->setPixmap(0,pixmap);
    return q;       
  }
  
- void packageDisplayWidget::openBinding(QListViewItem *index)
+ void packageDisplayWidget::openBinding(Q3ListViewItem *index)
  {
    if ( !index ) return; 
-   KURL url;
+   KUrl url;
    if (package && package->packageState == packageInfo::INSTALLED) {
      url.setPath( fileList->item2Path(index) ); // from local file to URL
-     (void) new KRun ( url ); // run the URL
+     (void) new KRun ( url,this ); // run the URL
    }
  }
 
-
 #include "packageDisplay.moc"
