@@ -1,3 +1,28 @@
+/*
+** Copyright (C) 2000 Peter Putzer <putzer@kde.org>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -9,31 +34,35 @@
 #include <stdlib.h>
 
 #include <qpainter.h>
-#include <qdragobject.h>
-#include <qdatastream.h>
-#include <qheader.h>
+#include <q3dragobject.h>
+#include <QDataStream>
+#include <q3header.h>
 #include <qpixmapcache.h>
 #include <qbitmap.h>
 #include <qcursor.h>
-#include <qcolor.h>
-#include <qcstring.h>
-#include <qlabel.h>
+#include <QColor>
+#include <q3cstring.h>
+#include <QLabel>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QFocusEvent>
+#include <QDropEvent>
+#include <Q3PopupMenu>
 
-#include <kapplication.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include "kdltooltip.h"
+//#include "kdltooltip.h"
 #include "ksv_core.h"
 #include "ksv_conf.h"
 #include "ksvdraglist.h"
 #include "ksvdrag.h"
 #include "ActionList.h"
 
-KSVItem::KSVItem (KListView* view)
-  : QListViewItem (view),
+KSVItem::KSVItem (K3ListView* view)
+  : Q3ListViewItem (view),
 	mData (new KSVData()),
     mConfig (KSVConfig::self()),
     mNewNormalColor (mConfig->newNormalColor()),
@@ -44,7 +73,7 @@ KSVItem::KSVItem (KListView* view)
 }
 
 KSVItem::KSVItem (const KSVItem& item)
-  : QListViewItem (item.listView()),
+  : Q3ListViewItem (item.listView()),
 	mData (new KSVData(*item.mData)),
     mConfig (KSVConfig::self()),
     mNewNormalColor (mConfig->newNormalColor()),
@@ -59,7 +88,7 @@ KSVItem::KSVItem (const KSVItem& item)
 }
 
 KSVItem::KSVItem (KSVDragList* view, const KSVData& data)
-  : QListViewItem (view),
+  : Q3ListViewItem (view),
 	mData (new KSVData (data)),
     mConfig (KSVConfig::self()),
     mNewNormalColor (mConfig->newNormalColor()),
@@ -85,8 +114,8 @@ QString KSVItem::key (int, bool) const
   return mData->numberString() + mData->label();
 }
 
-KSVItem::KSVItem (KListView* view, QString file, QString path, QString label, Q_INT8 nr )
-  : QListViewItem (view),
+KSVItem::KSVItem (K3ListView* view, QString file, QString path, QString label, qint8 nr )
+  : Q3ListViewItem (view),
 	mData (new KSVData (file, path, label, nr)),
     mConfig (KSVConfig::self()),
     mNewNormalColor (mConfig->newNormalColor()),
@@ -120,16 +149,16 @@ void KSVItem::paintCell (QPainter* p, const QColorGroup& cg, int column, int wid
 
   if (mData->newEntry())
 	{
-	  colors.setColor (QColorGroup::Text, mNewNormalColor);
-	  colors.setColor (QColorGroup::HighlightedText, mNewSelectedColor);
+	  colors.setColor (QPalette::Text, mNewNormalColor);
+	  colors.setColor (QPalette::HighlightedText, mNewSelectedColor);
 	}
   else if (mData->changed())
 	{
-	  colors.setColor (QColorGroup::Text, mChangedNormalColor);
-	  colors.setColor (QColorGroup::HighlightedText, mChangedSelectedColor);
+	  colors.setColor (QPalette::Text, mChangedNormalColor);
+	  colors.setColor (QPalette::HighlightedText, mChangedSelectedColor);
 	}
 
-  QListViewItem::paintCell (p, colors, column, width, align);
+  Q3ListViewItem::paintCell (p, colors, column, width, align);
 }
 
 QString KSVItem::toString() const
@@ -174,10 +203,10 @@ QPixmap KSVItem::paintDragIcon (const QFont& font, const QColorGroup&) const
   const int margin = listView()->itemMargin();
 
   const int width = icon.width() + margin * 2 + textRect.width();
-  const int height = kMax (icon.height(), textRect.height());
+  const int height = qMax (icon.height(), textRect.height());
 
   QPixmap result (width, height);
-  result.fill (white);
+  result.fill (Qt::white);
 
   QPainter p (&result);
   p.drawPixmap (0, 0, icon);
@@ -185,7 +214,7 @@ QPixmap KSVItem::paintDragIcon (const QFont& font, const QColorGroup&) const
 
   p.drawText (icon.width() + margin, 0,
 			  width, height,
-			  AlignLeft | AlignVCenter,
+			  Qt::AlignLeft | Qt::AlignVCenter,
 			  label());
   p.end();
 
@@ -193,24 +222,27 @@ QPixmap KSVItem::paintDragIcon (const QFont& font, const QColorGroup&) const
   p.begin (&mask);
   p.setFont (font);
 
-  p.fillRect (0, 0, width, height, color0);
+  p.fillRect (0, 0, width, height, Qt::color0);
 
-  p.setPen (color1);
+  p.setPen (Qt::color1);
   p.drawPixmap (0, 0, icon.createHeuristicMask());
 
   p.drawText (icon.width() + margin, 0,
 			  width, height,
-			  AlignLeft | AlignVCenter,
+			  Qt::AlignLeft | Qt::AlignVCenter,
 			  label());
 
-  QBrush brush (color0);
-  brush.setStyle(Dense5Pattern);
+  QBrush brush (Qt::color0);
+  brush.setStyle(Qt::Dense5Pattern);
   p.fillRect (0, 0, width, height, brush);
 
   p.end();
 
   result.setMask(mask);
-  result.setOptimization(QPixmap::BestOptim);
+#ifdef __GNUC__
+#warning "kde4: porting ?"  
+#endif  
+  //result.setOptimization(QPixmap::BestOptim);
   return result;
 }
 
@@ -236,7 +268,7 @@ void KSVItem::setFilename (const QString& file)
   mData->setFilename (file);
 }
 
-void KSVItem::setNumber (Q_INT8 nr)
+void KSVItem::setNumber (qint8 nr)
 {
   mData->setNumber (nr);
 
@@ -285,23 +317,23 @@ void KSVItem::setOriginalRunlevel (const QString& rl)
 //-----------------------
 
 KSVDragList::KSVDragList ( QWidget* parent, const char* name )
-  : KListView (parent, name),
+  : K3ListView (parent),
 	mItemToDrag (0L),
-	mDragMenu (new KPopupMenu (this)),
-	mDragCopyMenu (new KPopupMenu (this)),
-	mDragMoveMenu (new KPopupMenu (this)),
+	mDragMenu (new KMenu (this)),
+	mDragCopyMenu (new KMenu (this)),
+	mDragMoveMenu (new KMenu (this)),
 	mDisplayToolTips (true),
 	mCommonToolTips (true)
 {
   // add tooltips
-  toolTip=new KDLToolTip (this);
+  //toolTip=new KDLToolTip (this);
 
   setDragEnabled (true);
   setDragAutoScroll(true);
   setAcceptDrops(true);
   setDropVisualizer (true);
 
-  QHeader* h = header();
+  Q3Header* h = header();
   h->setClickEnabled (false);
 
   addColumn (i18n("No.")); // SortNumber
@@ -320,21 +352,21 @@ KSVDragList::KSVDragList ( QWidget* parent, const char* name )
   setSelectionModeExt (Single);
 
   // init DND menu
-  mDragMenu->insertTitle (i18n("Drag Menu"));
+  mDragMenu->addTitle (i18n("Drag Menu"));
   mDragMenu->insertItem ("&Copy", Copy);
   mDragMenu->insertItem ("&Move", Move);
 
-  mDragCopyMenu->insertTitle (i18n("Drag Menu"));
+  mDragCopyMenu->addTitle (i18n("Drag Menu"));
   mDragCopyMenu->insertItem ("&Copy", Copy);
 
-  mDragMoveMenu->insertTitle (i18n("Drag Menu"));
+  mDragMoveMenu->addTitle (i18n("Drag Menu"));
   mDragMoveMenu->insertItem ("&Move", Move);
 
   mRMList.setAutoDelete(true);
 
   // catch drops
-  connect (this, SIGNAL (dropped (QDropEvent*, QListViewItem*)),
-		   this, SLOT (drop (QDropEvent*, QListViewItem*)));
+  connect (this, SIGNAL (dropped (QDropEvent*, Q3ListViewItem*)),
+		   this, SLOT (drop (QDropEvent*, Q3ListViewItem*)));
 }
 
 KSVDragList::~KSVDragList()
@@ -342,10 +374,10 @@ KSVDragList::~KSVDragList()
   delete mDragMenu;
   delete mDragCopyMenu;
   delete mDragMoveMenu;
-  delete toolTip;
+  //delete toolTip;
 }
 
-void KSVDragList::initItem (QString file, QString path, QString name, Q_INT8 nr)
+void KSVDragList::initItem (QString file, QString path, QString name, qint8 nr)
 {
   KSVItem* tmp = new KSVItem(this, file, path, name, nr);
   tmp->setRunlevel(QObject::name());
@@ -355,7 +387,7 @@ void KSVDragList::initItem (QString file, QString path, QString name, Q_INT8 nr)
 
   setUpdatesEnabled(false);
 
-  // marked as new in insert, we dont want that
+  // marked as new in insert, we don't want that
   tmp->setNew(false);
   tmp->setChanged (false);
 
@@ -367,7 +399,7 @@ void KSVDragList::setDefaultIcon (const QPixmap& icon)
 {
   mIcon = icon;
 
-  for (QListViewItemIterator it (firstChild()); it.current(); ++it)
+  for (Q3ListViewItemIterator it (firstChild()); it.current(); ++it)
     {
 	  static_cast <KSVItem*> (it.current())->setIcon (mIcon);
     }
@@ -375,7 +407,7 @@ void KSVDragList::setDefaultIcon (const QPixmap& icon)
 
 void KSVDragList::clear ()
 {
-  KListView::clear();
+  K3ListView::clear();
 
   clearRMList();
 }
@@ -385,7 +417,7 @@ void KSVDragList::setNewNormalColor ( const QColor& col )
   mNewNormalColor = col;
 
   KSVItem* item;
-  for (QListViewItemIterator it (firstChild());
+  for (Q3ListViewItemIterator it (firstChild());
 	   (item = static_cast<KSVItem*>(it.current()));
 	   ++it)
     {
@@ -398,7 +430,7 @@ void KSVDragList::setNewSelectedColor (const QColor& col)
   mNewSelectedColor = col;
 
   KSVItem* item;
-  for (QListViewItemIterator it (firstChild());
+  for (Q3ListViewItemIterator it (firstChild());
 	   (item = static_cast<KSVItem*>(it.current()));
 	   ++it)
     {
@@ -406,12 +438,12 @@ void KSVDragList::setNewSelectedColor (const QColor& col)
     }
 }
 
-Q_INT8 KSVDragList::generateNumber (const QString& label,
+qint8 KSVDragList::generateNumber (const QString& label,
                                     const KSVData* itemBelow, const KSVData* itemAbove) const
 {
-  Q_INT8 high = itemBelow ? itemBelow->number() : -1;
-  Q_INT8 low = itemAbove ? itemAbove->number() : -1;
-  Q_INT8 result = generateNumber (high, low);
+  qint8 high = itemBelow ? itemBelow->number() : -1;
+  qint8 low = itemAbove ? itemAbove->number() : -1;
+  qint8 result = generateNumber (high, low);
 
   if (high == result && result != -1 && label >= itemBelow->label())
     result = -1;
@@ -422,11 +454,11 @@ Q_INT8 KSVDragList::generateNumber (const QString& label,
   return result;
 }
 
-Q_INT8 KSVDragList::generateNumber (Q_INT8 high, Q_INT8 low) const
+qint8 KSVDragList::generateNumber (qint8 high, qint8 low) const
 {
   Q_ASSERT (high >= low || high == -1);
 
-  Q_INT8 result = -1;
+  qint8 result = -1;
 
   if (low < 0)
 	{
@@ -448,7 +480,7 @@ void KSVDragList::setChangedNormalColor (const QColor& col)
   mChangedNormalColor = col;
 
   KSVItem* item;
-  for (QListViewItemIterator it (firstChild());
+  for (Q3ListViewItemIterator it (firstChild());
 	   (item = static_cast<KSVItem*> (it.current()));
 	   ++it)
     {
@@ -461,7 +493,7 @@ void KSVDragList::setChangedSelectedColor (const QColor& col)
   mChangedSelectedColor = col;
 
   KSVItem* item;
-  for (QListViewItemIterator it (firstChild());
+  for (Q3ListViewItemIterator it (firstChild());
 	   (item = static_cast<KSVItem*> (it.current()));
 	   ++it)
     {
@@ -473,7 +505,7 @@ KSVItem* KSVDragList::match (const KSVData& data)
 {
   KSVItem* res = 0L;
 
-  for (QListViewItemIterator it (this);
+  for (Q3ListViewItemIterator it (this);
 	   (res = static_cast<KSVItem*> (it.current()));
 	   ++it)
     {
@@ -514,7 +546,7 @@ void KSVDragList::startDrag ()
 }
 
 //KSVDrag* KSVDragList::dragObject ()
-QDragObject* KSVDragList::dragObject ()
+Q3DragObject* KSVDragList::dragObject ()
 {
   if (mItemToDrag)
 	{
@@ -533,7 +565,7 @@ bool KSVDragList::acceptDrag (QDropEvent* e) const
 
 void KSVDragList::focusInEvent (QFocusEvent* e)
 {
-  KListView::focusInEvent(e);
+  K3ListView::focusInEvent(e);
 
   if (!currentItem())
 	setCurrentItem (firstChild());
@@ -550,7 +582,7 @@ bool KSVDragList::removeFromRMList (const KSVData& item)
 {
   KSVData* res = 0L;
 
-  for (QPtrListIterator<KSVData> it (mRMList);
+  for (Q3PtrListIterator<KSVData> it (mRMList);
 	   it.current();
 	   ++it)
 	{
@@ -570,7 +602,7 @@ bool KSVDragList::removeFromRMList (const KSVData& item)
 
 bool KSVDragList::insert (const KSVData& data, const KSVData* above, const KSVData* below)
 {
-  Q_INT8 nr = generateNumber (data.label(), below, above);
+  qint8 nr = generateNumber (data.label(), below, above);
 
   if (nr > -1)
 	{
@@ -614,7 +646,7 @@ bool KSVDragList::insert (const KSVData& data, const KSVItem* where, KSVAction*&
 	  if (exists->data() == above || exists->data() == below)
 		return false;
 
-	  Q_INT8 nr = generateNumber (exists->label(), below, above);
+	  qint8 nr = generateNumber (exists->label(), below, above);
 
 	  if (nr == -1)
 		{
@@ -641,15 +673,11 @@ bool KSVDragList::insert (const KSVData& data, const KSVItem* where, KSVAction*&
   return success;
 }
 
-void KSVDragList::drop (QDropEvent* e, QListViewItem* after)
+void KSVDragList::drop (QDropEvent* e, Q3ListViewItem* after)
 {
   KSVData data;
   KSVDragList* source = static_cast<KSVDragList*> (e->source());
-  QPopupMenu* menu = 0L;
-
-  // hack to empty the cursor stack after DND
-  QApplication::restoreOverrideCursor();
-  QApplication::restoreOverrideCursor();
+  QMenu* menu = 0L;
 
   if ((!source) || (!strcmp(source->name(), "Scripts")))
 	menu = mDragCopyMenu;
@@ -665,7 +693,12 @@ void KSVDragList::drop (QDropEvent* e, QListViewItem* after)
 	  if (e->action() == QDropEvent::Copy && source != this)
 		res = Copy;
 	  else
-		res = menu->exec (QCursor::pos(), 1);
+	  {	
+#ifdef __GNUC__
+#warning "kde4: porting"			  
+#endif
+		//res = menu->exec (QCursor::pos(), 1);
+	  }
 
 	  if (res == -1) // operation cancelled
 		return;
@@ -695,7 +728,7 @@ bool KSVDragList::addToRMList (const KSVData& item)
 {
   KSVData* res = 0L;
 
-  for (QPtrListIterator<KSVData> it (mRMList);
+  for (Q3PtrListIterator<KSVData> it (mRMList);
 	   it.current();
 	   ++it)
 	{
@@ -718,7 +751,11 @@ bool KSVDragList::addToRMList (const KSVData& item)
 
 void KSVDragList::setEnabled (bool enable)
 {
-  if (enable)
+#ifdef __GNUC__
+#warning "kde4: porting!!!!!!!!!!!"		
+#endif
+#if 0
+		if (enable)
     clearWState (WState_ForceDisabled);
   else
     setWState (WState_ForceDisabled);
@@ -745,7 +782,7 @@ void KSVDragList::setEnabled (bool enable)
           enabledChange (FALSE);
         }
     }
-
+#endif
   viewport()->setEnabled (enable);
 }
 
